summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-28 22:19:14 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-28 22:19:14 +0000
commitee2ed42c72935932a756dedfe797d96bd0205e31 (patch)
treeaee48705aeabd69a6b7c1b08510c3309484b1561
parentad9a072a78fea6d59e142716ca4104687490bfc6 (diff)
downloadchromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.zip
chromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.tar.gz
chromium_src-ee2ed42c72935932a756dedfe797d96bd0205e31.tar.bz2
Favicon file shuffling.
Moves them to their own directory, renames the Helper to TabHelper in prep for moving it to TabContentsWrapper. BUG=71097 TEST=none Review URL: http://codereview.chromium.org/6902125 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@83425 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/browser/bookmarks/bookmark_model.h2
-rw-r--r--chrome/browser/custom_home_pages_table_model.h4
-rw-r--r--chrome/browser/extensions/extension_web_ui.h2
-rw-r--r--chrome/browser/favicon/favicon_handler.cc (renamed from chrome/browser/favicon_handler.cc)8
-rw-r--r--chrome/browser/favicon/favicon_handler.h (renamed from chrome/browser/favicon_handler.h)20
-rw-r--r--chrome/browser/favicon/favicon_handler_unittest.cc (renamed from chrome/browser/favicon_handler_unittest.cc)2
-rw-r--r--chrome/browser/favicon/favicon_service.cc (renamed from chrome/browser/favicon_service.cc)2
-rw-r--r--chrome/browser/favicon/favicon_service.h (renamed from chrome/browser/favicon_service.h)6
-rw-r--r--chrome/browser/favicon/favicon_tab_helper.cc (renamed from chrome/browser/favicon_helper.cc)26
-rw-r--r--chrome/browser/favicon/favicon_tab_helper.h (renamed from chrome/browser/favicon_helper.h)24
-rw-r--r--chrome/browser/history/history.h2
-rw-r--r--chrome/browser/history/history_marshaling.h8
-rw-r--r--chrome/browser/instant/instant_loader.cc2
-rw-r--r--chrome/browser/jumplist_win.cc2
-rw-r--r--chrome/browser/possible_url_model.cc4
-rw-r--r--chrome/browser/profiles/profile_impl.cc2
-rw-r--r--chrome/browser/sync/glue/bookmark_change_processor.cc2
-rw-r--r--chrome/browser/ui/cocoa/history_menu_bridge.h2
-rw-r--r--chrome/browser/ui/cocoa/hung_renderer_controller.mm2
-rw-r--r--chrome/browser/ui/gtk/global_history_menu.cc2
-rw-r--r--chrome/browser/ui/gtk/global_history_menu.h2
-rw-r--r--chrome/browser/ui/search_engines/template_url_table_model.cc2
-rw-r--r--chrome/browser/ui/toolbar/back_forward_menu_model.h2
-rw-r--r--chrome/browser/ui/webui/chrome_web_ui_factory.h2
-rw-r--r--chrome/browser/ui/webui/extension_icon_source.h2
-rw-r--r--chrome/browser/ui/webui/favicon_source.h2
-rw-r--r--chrome/chrome_browser.gypi12
-rw-r--r--chrome/chrome_tests.gypi2
-rw-r--r--chrome/test/testing_profile.cc2
-rw-r--r--content/browser/tab_contents/tab_contents.cc6
-rw-r--r--content/browser/tab_contents/tab_contents.h10
31 files changed, 84 insertions, 84 deletions
diff --git a/chrome/browser/bookmarks/bookmark_model.h b/chrome/browser/bookmarks/bookmark_model.h
index 1dd62112..0e4ada68 100644
--- a/chrome/browser/bookmarks/bookmark_model.h
+++ b/chrome/browser/bookmarks/bookmark_model.h
@@ -17,7 +17,7 @@
#include "base/synchronization/waitable_event.h"
#include "chrome/browser/bookmarks/bookmark_model_observer.h"
#include "chrome/browser/bookmarks/bookmark_service.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/history_types.h"
#include "content/browser/cancelable_request.h"
diff --git a/chrome/browser/custom_home_pages_table_model.h b/chrome/browser/custom_home_pages_table_model.h
index 875818e..5145564 100644
--- a/chrome/browser/custom_home_pages_table_model.h
+++ b/chrome/browser/custom_home_pages_table_model.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -11,7 +11,7 @@
#include "base/compiler_specific.h"
#include "chrome/browser/history/history.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "ui/base/models/table_model.h"
class GURL;
diff --git a/chrome/browser/extensions/extension_web_ui.h b/chrome/browser/extensions/extension_web_ui.h
index f41ead3..ef7f5e9 100644
--- a/chrome/browser/extensions/extension_web_ui.h
+++ b/chrome/browser/extensions/extension_web_ui.h
@@ -11,7 +11,7 @@
#include "base/memory/scoped_ptr.h"
#include "chrome/browser/extensions/extension_bookmark_manager_api.h"
#include "chrome/browser/extensions/extension_function_dispatcher.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/common/extensions/extension.h"
#include "content/browser/webui/web_ui.h"
#include "ipc/ipc_channel.h"
diff --git a/chrome/browser/favicon_handler.cc b/chrome/browser/favicon/favicon_handler.cc
index 0ae2063..66d2b47 100644
--- a/chrome/browser/favicon_handler.cc
+++ b/chrome/browser/favicon/favicon_handler.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/favicon_handler.h"
+#include "chrome/browser/favicon/favicon_handler.h"
#include "build/build_config.h"
@@ -57,7 +57,7 @@ FaviconHandler::DownloadRequest::DownloadRequest()
FaviconHandler::DownloadRequest::DownloadRequest(
const GURL& url,
const GURL& image_url,
- FaviconHelper::ImageDownloadCallback* callback,
+ FaviconTabHelper::ImageDownloadCallback* callback,
history::IconType icon_type)
: url(url),
image_url(image_url),
@@ -108,7 +108,7 @@ int FaviconHandler::DownloadImage(
const GURL& image_url,
int image_size,
history::IconType icon_type,
- FaviconHelper::ImageDownloadCallback* callback) {
+ FaviconTabHelper::ImageDownloadCallback* callback) {
DCHECK(callback); // Must provide a callback.
return ScheduleDownload(GURL(), image_url, image_size, icon_type, callback);
}
@@ -423,7 +423,7 @@ int FaviconHandler::ScheduleDownload(
const GURL& image_url,
int image_size,
history::IconType icon_type,
- FaviconHelper::ImageDownloadCallback* callback) {
+ FaviconTabHelper::ImageDownloadCallback* callback) {
const int download_id = DownloadFavicon(image_url, image_size);
if (download_id) {
// Download ids should be unique.
diff --git a/chrome/browser/favicon_handler_unittest.cc b/chrome/browser/favicon/favicon_handler_unittest.cc
index 0f68ea2..dc26ef5 100644
--- a/chrome/browser/favicon_handler_unittest.cc
+++ b/chrome/browser/favicon/favicon_handler_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/favicon_handler.h"
+#include "chrome/browser/favicon/favicon_handler.h"
#include "content/browser/renderer_host/test_render_view_host.h"
#include "content/browser/tab_contents/navigation_entry.h"
#include "content/browser/tab_contents/test_tab_contents.h"
diff --git a/chrome/browser/favicon_service.cc b/chrome/browser/favicon/favicon_service.cc
index 05caa22..a276c7c 100644
--- a/chrome/browser/favicon_service.cc
+++ b/chrome/browser/favicon/favicon_service.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/history_backend.h"
diff --git a/chrome/browser/favicon_service.h b/chrome/browser/favicon/favicon_service.h
index 1eb1adb..48d81e8 100644
--- a/chrome/browser/favicon_service.h
+++ b/chrome/browser/favicon/favicon_service.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_FAVICON_SERVICE_H__
-#define CHROME_BROWSER_FAVICON_SERVICE_H__
+#ifndef CHROME_BROWSER_FAVICON_FAVICON_SERVICE_H_
+#define CHROME_BROWSER_FAVICON_FAVICON_SERVICE_H_
#pragma once
#include <vector>
@@ -103,4 +103,4 @@ class FaviconService : public CancelableRequestProvider,
DISALLOW_COPY_AND_ASSIGN(FaviconService);
};
-#endif // CHROME_BROWSER_FAVICON_SERVICE_H__
+#endif // CHROME_BROWSER_FAVICON_FAVICON_SERVICE_H_
diff --git a/chrome/browser/favicon_helper.cc b/chrome/browser/favicon/favicon_tab_helper.cc
index 653b096..f6908fb 100644
--- a/chrome/browser/favicon_helper.cc
+++ b/chrome/browser/favicon/favicon_tab_helper.cc
@@ -2,13 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/favicon_helper.h"
+#include "chrome/browser/favicon/favicon_tab_helper.h"
#include "chrome/browser/defaults.h"
-#include "chrome/browser/favicon_handler.h"
+#include "chrome/browser/favicon/favicon_handler.h"
#include "chrome/common/icon_messages.h"
-FaviconHelper::FaviconHelper(TabContents* tab_contents)
+FaviconTabHelper::FaviconTabHelper(TabContents* tab_contents)
: TabContentsObserver(tab_contents) {
favicon_handler_.reset(new FaviconHandler(tab_contents,
FaviconHandler::FAVICON));
@@ -17,16 +17,16 @@ FaviconHelper::FaviconHelper(TabContents* tab_contents)
FaviconHandler::TOUCH));
}
-FaviconHelper::~FaviconHelper() {
+FaviconTabHelper::~FaviconTabHelper() {
}
-void FaviconHelper::FetchFavicon(const GURL& url) {
+void FaviconTabHelper::FetchFavicon(const GURL& url) {
favicon_handler_->FetchFavicon(url);
if (touch_icon_handler_.get())
touch_icon_handler_->FetchFavicon(url);
}
-int FaviconHelper::DownloadImage(const GURL& image_url,
+int FaviconTabHelper::DownloadImage(const GURL& image_url,
int image_size,
history::IconType icon_type,
ImageDownloadCallback* callback) {
@@ -39,9 +39,9 @@ int FaviconHelper::DownloadImage(const GURL& image_url,
return 0;
}
-bool FaviconHelper::OnMessageReceived(const IPC::Message& message) {
+bool FaviconTabHelper::OnMessageReceived(const IPC::Message& message) {
bool message_handled = true;
- IPC_BEGIN_MESSAGE_MAP(FaviconHelper, message)
+ IPC_BEGIN_MESSAGE_MAP(FaviconTabHelper, message)
IPC_MESSAGE_HANDLER(IconHostMsg_DidDownloadFavicon, OnDidDownloadFavicon)
IPC_MESSAGE_HANDLER(IconHostMsg_UpdateFaviconURL, OnUpdateFaviconURL)
IPC_MESSAGE_UNHANDLED(message_handled = false)
@@ -49,16 +49,16 @@ bool FaviconHelper::OnMessageReceived(const IPC::Message& message) {
return message_handled;
}
-void FaviconHelper::OnDidDownloadFavicon(int id,
- const GURL& image_url,
- bool errored,
- const SkBitmap& image) {
+void FaviconTabHelper::OnDidDownloadFavicon(int id,
+ const GURL& image_url,
+ bool errored,
+ const SkBitmap& image) {
favicon_handler_->OnDidDownloadFavicon(id, image_url, errored, image);
if (touch_icon_handler_.get())
touch_icon_handler_->OnDidDownloadFavicon(id, image_url, errored, image);
}
-void FaviconHelper::OnUpdateFaviconURL(
+void FaviconTabHelper::OnUpdateFaviconURL(
int32 page_id,
const std::vector<FaviconURL>& candidates) {
favicon_handler_->OnUpdateFaviconURL(page_id, candidates);
diff --git a/chrome/browser/history/history.h b/chrome/browser/history/history.h
index 9b8a70a..95c40d5 100644
--- a/chrome/browser/history/history.h
+++ b/chrome/browser/history/history.h
@@ -17,7 +17,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/string16.h"
#include "base/task.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history_types.h"
#include "chrome/browser/search_engines/template_url_id.h"
#include "chrome/common/ref_counted_util.h"
diff --git a/chrome/browser/history/history_marshaling.h b/chrome/browser/history/history_marshaling.h
index e721907..f063fe79 100644
--- a/chrome/browser/history/history_marshaling.h
+++ b/chrome/browser/history/history_marshaling.h
@@ -5,12 +5,12 @@
// Data structures for communication between the history service on the main
// thread and the backend on the history thread.
-#ifndef CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H__
-#define CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H__
+#ifndef CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H_
+#define CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H_
#pragma once
#include "base/memory/scoped_vector.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/page_usage_data.h"
#include "content/browser/cancelable_request.h"
@@ -91,4 +91,4 @@ typedef CancelableRequest1<HistoryService::HistoryDBTaskCallback,
} // namespace history
-#endif // CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H__
+#endif // CHROME_BROWSER_HISTORY_HISTORY_MARSHALING_H_
diff --git a/chrome/browser/instant/instant_loader.cc b/chrome/browser/instant/instant_loader.cc
index f83b50a..88db44b 100644
--- a/chrome/browser/instant/instant_loader.cc
+++ b/chrome/browser/instant/instant_loader.cc
@@ -14,7 +14,7 @@
#include "base/timer.h"
#include "base/utf_string_conversions.h"
#include "base/values.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history_marshaling.h"
#include "chrome/browser/instant/instant_loader_delegate.h"
#include "chrome/browser/profiles/profile.h"
diff --git a/chrome/browser/jumplist_win.cc b/chrome/browser/jumplist_win.cc
index e60e4ba..577ccf5 100644
--- a/chrome/browser/jumplist_win.cc
+++ b/chrome/browser/jumplist_win.cc
@@ -21,7 +21,7 @@
#include "base/utf_string_conversions.h"
#include "base/win/scoped_comptr.h"
#include "base/win/windows_version.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/page_usage_data.h"
#include "chrome/browser/profiles/profile.h"
diff --git a/chrome/browser/possible_url_model.cc b/chrome/browser/possible_url_model.cc
index 2d30c51..15b5917 100644
--- a/chrome/browser/possible_url_model.cc
+++ b/chrome/browser/possible_url_model.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -8,7 +8,7 @@
#include "base/i18n/rtl.h"
#include "base/string_util.h"
#include "base/utf_string_conversions.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/prefs/pref_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/common/pref_names.h"
diff --git a/chrome/browser/profiles/profile_impl.cc b/chrome/browser/profiles/profile_impl.cc
index 4be2dff..b4cccce 100644
--- a/chrome/browser/profiles/profile_impl.cc
+++ b/chrome/browser/profiles/profile_impl.cc
@@ -35,7 +35,7 @@
#include "chrome/browser/extensions/extension_service.h"
#include "chrome/browser/extensions/extension_special_storage_policy.h"
#include "chrome/browser/extensions/user_script_master.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/geolocation/geolocation_content_settings_map.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/top_sites.h"
diff --git a/chrome/browser/sync/glue/bookmark_change_processor.cc b/chrome/browser/sync/glue/bookmark_change_processor.cc
index d05fb79..8554833 100644
--- a/chrome/browser/sync/glue/bookmark_change_processor.cc
+++ b/chrome/browser/sync/glue/bookmark_change_processor.cc
@@ -11,7 +11,7 @@
#include "base/utf_string_conversions.h"
#include "chrome/browser/bookmarks/bookmark_utils.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/sync/profile_sync_service.h"
#include "content/browser/browser_thread.h"
diff --git a/chrome/browser/ui/cocoa/history_menu_bridge.h b/chrome/browser/ui/cocoa/history_menu_bridge.h
index 09cd694..5ad9fa8 100644
--- a/chrome/browser/ui/cocoa/history_menu_bridge.h
+++ b/chrome/browser/ui/cocoa/history_menu_bridge.h
@@ -11,7 +11,7 @@
#include "base/memory/ref_counted.h"
#include "base/memory/scoped_nsobject.h"
-#import "chrome/browser/favicon_service.h"
+#import "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/sessions/session_id.h"
#include "chrome/browser/sessions/tab_restore_service.h"
diff --git a/chrome/browser/ui/cocoa/hung_renderer_controller.mm b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
index 0d4b341..3334bfe 100644
--- a/chrome/browser/ui/cocoa/hung_renderer_controller.mm
+++ b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
@@ -10,7 +10,7 @@
#include "base/mac/mac_util.h"
#include "base/process_util.h"
#include "base/sys_string_conversions.h"
-#include "chrome/browser/favicon_helper.h"
+#include "chrome/browser/favicon/favicon_tab_helper.h"
#include "chrome/browser/ui/browser_dialogs.h"
#include "chrome/browser/ui/browser_list.h"
#import "chrome/browser/ui/cocoa/multi_key_equivalent_button.h"
diff --git a/chrome/browser/ui/gtk/global_history_menu.cc b/chrome/browser/ui/gtk/global_history_menu.cc
index 1fe561f..eb1f87c 100644
--- a/chrome/browser/ui/gtk/global_history_menu.cc
+++ b/chrome/browser/ui/gtk/global_history_menu.cc
@@ -9,7 +9,7 @@
#include "base/stl_util-inl.h"
#include "base/utf_string_conversions.h"
#include "base/string_number_conversions.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/sessions/tab_restore_service.h"
#include "chrome/browser/sessions/tab_restore_service_factory.h"
diff --git a/chrome/browser/ui/gtk/global_history_menu.h b/chrome/browser/ui/gtk/global_history_menu.h
index fff3c99..d523ee5 100644
--- a/chrome/browser/ui/gtk/global_history_menu.h
+++ b/chrome/browser/ui/gtk/global_history_menu.h
@@ -8,7 +8,7 @@
#include <map>
#include "content/browser/cancelable_request.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/sessions/tab_restore_service.h"
#include "chrome/browser/sessions/tab_restore_service_observer.h"
#include "content/common/notification_observer.h"
diff --git a/chrome/browser/ui/search_engines/template_url_table_model.cc b/chrome/browser/ui/search_engines/template_url_table_model.cc
index 5c50a08..3617ecc 100644
--- a/chrome/browser/ui/search_engines/template_url_table_model.cc
+++ b/chrome/browser/ui/search_engines/template_url_table_model.cc
@@ -8,7 +8,7 @@
#include "base/i18n/rtl.h"
#include "base/stl_util-inl.h"
#include "base/utf_string_conversions.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/search_engines/template_url.h"
#include "chrome/browser/search_engines/template_url_model.h"
diff --git a/chrome/browser/ui/toolbar/back_forward_menu_model.h b/chrome/browser/ui/toolbar/back_forward_menu_model.h
index efbe0b3..ad6a548 100644
--- a/chrome/browser/ui/toolbar/back_forward_menu_model.h
+++ b/chrome/browser/ui/toolbar/back_forward_menu_model.h
@@ -12,7 +12,7 @@
#include "base/basictypes.h"
#include "base/gtest_prod_util.h"
#include "base/string16.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "ui/base/models/menu_model.h"
#include "webkit/glue/window_open_disposition.h"
diff --git a/chrome/browser/ui/webui/chrome_web_ui_factory.h b/chrome/browser/ui/webui/chrome_web_ui_factory.h
index c8c0b1b..0214baa 100644
--- a/chrome/browser/ui/webui/chrome_web_ui_factory.h
+++ b/chrome/browser/ui/webui/chrome_web_ui_factory.h
@@ -10,7 +10,7 @@
#include "base/memory/singleton.h"
#include "content/browser/webui/web_ui.h"
#include "content/browser/webui/web_ui_factory.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
class WebUI;
class GURL;
diff --git a/chrome/browser/ui/webui/extension_icon_source.h b/chrome/browser/ui/webui/extension_icon_source.h
index ca1338a..745be27 100644
--- a/chrome/browser/ui/webui/extension_icon_source.h
+++ b/chrome/browser/ui/webui/extension_icon_source.h
@@ -10,7 +10,7 @@
#include "base/basictypes.h"
#include "chrome/browser/extensions/image_loading_tracker.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/ui/webui/chrome_url_data_manager.h"
#include "chrome/common/extensions/extension.h"
#include "third_party/skia/include/core/SkBitmap.h"
diff --git a/chrome/browser/ui/webui/favicon_source.h b/chrome/browser/ui/webui/favicon_source.h
index 73a9091..2121b28 100644
--- a/chrome/browser/ui/webui/favicon_source.h
+++ b/chrome/browser/ui/webui/favicon_source.h
@@ -10,7 +10,7 @@
#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/ui/webui/chrome_url_data_manager.h"
class GURL;
diff --git a/chrome/chrome_browser.gypi b/chrome/chrome_browser.gypi
index ae8e1e2..51720b7 100644
--- a/chrome/chrome_browser.gypi
+++ b/chrome/chrome_browser.gypi
@@ -1045,12 +1045,12 @@
'browser/external_protocol_handler.h',
'browser/external_tab_container_win.cc',
'browser/external_tab_container_win.h',
- 'browser/favicon_handler.cc',
- 'browser/favicon_handler.h',
- 'browser/favicon_helper.cc',
- 'browser/favicon_helper.h',
- 'browser/favicon_service.cc',
- 'browser/favicon_service.h',
+ 'browser/favicon/favicon_handler.cc',
+ 'browser/favicon/favicon_handler.h',
+ 'browser/favicon/favicon_service.cc',
+ 'browser/favicon/favicon_service.h',
+ 'browser/favicon/favicon_tab_helper.cc',
+ 'browser/favicon/favicon_tab_helper.h',
'browser/file_select_helper.cc',
'browser/file_select_helper.h',
'browser/first_run/first_run.cc',
diff --git a/chrome/chrome_tests.gypi b/chrome/chrome_tests.gypi
index a0f6af2..ffb2c4c 100644
--- a/chrome/chrome_tests.gypi
+++ b/chrome/chrome_tests.gypi
@@ -1353,7 +1353,7 @@
'browser/extensions/sandboxed_extension_unpacker_unittest.cc',
'browser/extensions/user_script_listener_unittest.cc',
'browser/extensions/user_script_master_unittest.cc',
- 'browser/favicon_handler_unittest.cc',
+ 'browser/favicon/favicon_handler_unittest.cc',
'browser/first_run/first_run_unittest.cc',
'browser/geolocation/geolocation_content_settings_map_unittest.cc',
'browser/geolocation/geolocation_exceptions_table_model_unittest.cc',
diff --git a/chrome/test/testing_profile.cc b/chrome/test/testing_profile.cc
index c983c2d..03caad3 100644
--- a/chrome/test/testing_profile.cc
+++ b/chrome/test/testing_profile.cc
@@ -20,7 +20,7 @@
#include "chrome/browser/extensions/extension_pref_value_map.h"
#include "chrome/browser/extensions/extension_service.h"
#include "chrome/browser/extensions/extension_special_storage_policy.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/geolocation/geolocation_content_settings_map.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/history_backend.h"
diff --git a/content/browser/tab_contents/tab_contents.cc b/content/browser/tab_contents/tab_contents.cc
index ed362a3..00a58c3 100644
--- a/content/browser/tab_contents/tab_contents.cc
+++ b/content/browser/tab_contents/tab_contents.cc
@@ -25,7 +25,7 @@
#include "chrome/browser/download/download_manager.h"
#include "chrome/browser/download/download_request_limiter.h"
#include "chrome/browser/external_protocol_handler.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/browser/google/google_util.h"
#include "chrome/browser/history/history.h"
#include "chrome/browser/history/history_types.h"
@@ -357,7 +357,7 @@ TabContents::~TabContents() {
}
void TabContents::AddObservers() {
- favicon_helper_.reset(new FaviconHelper(this));
+ favicon_tab_helper_.reset(new FaviconTabHelper(this));
plugin_observer_.reset(new PluginObserver(this));
safebrowsing_detection_host_.reset(new safe_browsing::ClientSideDetectionHost(
this));
@@ -1429,7 +1429,7 @@ void TabContents::DidNavigateMainFramePostCommit(
received_page_title_ = false;
// Get the favicon, either from history or request it from the net.
- favicon_helper_->FetchFavicon(details.entry->url());
+ favicon_tab_helper_->FetchFavicon(details.entry->url());
// Clear all page actions, blocked content notifications and browser actions
// for this tab, unless this is an in-page navigation.
diff --git a/chrome/browser/favicon_handler.h b/chrome/browser/favicon/favicon_handler.h
index 9fa4c21..8cc26be 100644
--- a/chrome/browser/favicon_handler.h
+++ b/chrome/browser/favicon/favicon_handler.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_FAVICON_HANDLER_H__
-#define CHROME_BROWSER_FAVICON_HANDLER_H__
+#ifndef CHROME_BROWSER_FAVICON_FAVICON_HANDLER_H_
+#define CHROME_BROWSER_FAVICON_FAVICON_HANDLER_H_
#pragma once
#include <map>
@@ -11,8 +11,8 @@
#include "base/basictypes.h"
#include "base/callback.h"
#include "base/memory/ref_counted.h"
-#include "chrome/browser/favicon_helper.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
+#include "chrome/browser/favicon/favicon_tab_helper.h"
#include "chrome/common/favicon_url.h"
#include "chrome/common/ref_counted_util.h"
#include "content/browser/cancelable_request.h"
@@ -25,7 +25,7 @@ class RefCountedMemory;
class SkBitmap;
class TabContents;
// FaviconHandler works with FaviconHelper to fetch the specific type of
// favicon.
//
// FetchFavicon requests the favicon from the favicon service which in turn
@@ -91,7 +91,7 @@ class FaviconHandler {
int DownloadImage(const GURL& image_url,
int image_size,
history::IconType icon_type,
- FaviconHelper::ImageDownloadCallback* callback);
+ FaviconTabHelper::ImageDownloadCallback* callback);
// Message Handler. Must be public, because also called from
// PrerenderContents.
@@ -152,12 +152,12 @@ class FaviconHandler {
DownloadRequest(const GURL& url,
const GURL& image_url,
- FaviconHelper::ImageDownloadCallback* callback,
+ FaviconTabHelper::ImageDownloadCallback* callback,
history::IconType icon_type);
GURL url;
GURL image_url;
- FaviconHelper::ImageDownloadCallback* callback;
+ FaviconTabHelper::ImageDownloadCallback* callback;
history::IconType icon_type;
};
@@ -182,7 +182,7 @@ class FaviconHandler {
const GURL& image_url,
int image_size,
history::IconType icon_type,
- FaviconHelper::ImageDownloadCallback* callback);
+ FaviconTabHelper::ImageDownloadCallback* callback);
// Sets the image data for the favicon. This is invoked asynchronously after
// we request the TabContents to download the favicon.
@@ -258,4 +258,4 @@ class FaviconHandler {
DISALLOW_COPY_AND_ASSIGN(FaviconHandler);
};
-#endif // CHROME_BROWSER_FAVICON_HANDLER_H__
+#endif // CHROME_BROWSER_FAVICON_FAVICON_HANDLER_H_
@@ -25,7 +25,7 @@ class RefCountedMemory;
class SkBitmap;
class TabContents;
-// FaviconHandler works with FaviconHelper to fetch the specific type of
+// FaviconHandler works with FaviconTabHelper to fetch the specific type of
// favicon.
//
diff --git a/chrome/browser/favicon_helper.h b/chrome/browser/favicon/favicon_tab_helper.h
index 7bdd4d0..64064f4 100644
--- a/chrome/browser/favicon_helper.h
+++ b/chrome/browser/favicon/favicon_tab_helper.h
@@ -2,13 +2,13 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_FAVICON_HELPER_H__
-#define CHROME_BROWSER_FAVICON_HELPER_H__
+#ifndef CHROME_BROWSER_FAVICON_FAVICON_TAB_HELPER_H_
+#define CHROME_BROWSER_FAVICON_FAVICON_TAB_HELPER_H_
#pragma once
#include "base/basictypes.h"
#include "base/callback.h"
-#include "chrome/browser/favicon_service.h"
+#include "chrome/browser/favicon/favicon_service.h"
#include "chrome/common/favicon_url.h"
#include "content/browser/tab_contents/tab_contents_observer.h"
#include "googleurl/src/gurl.h"
@@ -20,19 +20,19 @@ class RefCountedMemory;
class SkBitmap;
class TabContents;
// FaviconHelper works with FaviconHandlers to fetch the favicons.
//
-// FetchFavicon fetchs the give page's icons. It requests the icons from history
-// backend. If the icon is not available or expired, the icon will be
-// downloaded and saved in history backend.
+// FetchFavicon fetches the given page's icons. It requests the icons from the
+// history backend. If the icon is not available or expired, the icon will be
+// downloaded and saved in the history backend.
//
// DownloadImage downloads the specified icon and returns it through the given
// callback.
//
-class FaviconHelper : public TabContentsObserver {
+class FaviconTabHelper : public TabContentsObserver {
public:
- explicit FaviconHelper(TabContents* tab_contents);
- virtual ~FaviconHelper();
+ explicit FaviconTabHelper(TabContents* tab_contents);
+ virtual ~FaviconTabHelper();
// Initiates loading the favicon for the specified url.
void FetchFavicon(const GURL& url);
@@ -70,7 +70,7 @@ class FaviconHelper : public TabContentsObserver {
// browser_defaults::kEnableTouchIcon is false.
scoped_ptr<FaviconHandler> touch_icon_handler_;
- DISALLOW_COPY_AND_ASSIGN(FaviconHelper);
+ DISALLOW_COPY_AND_ASSIGN(FaviconTabHelper);
};
-#endif // CHROME_BROWSER_FAVICON_HELPER_H__
+#endif // CHROME_BROWSER_FAVICON_FAVICON_TAB_HELPER_H_
@@ -20,19 +20,19 @@ class RefCountedMemory;
class SkBitmap;
class TabContents;
-// FaviconHelper works with FaviconHandlers to fetch the favicons.
+// FaviconTabHelper works with FaviconHandlers to fetch the favicons.
//
diff --git a/content/browser/tab_contents/tab_contents.h b/content/browser/tab_contents/tab_contents.h
index 5d3cd23..5fe5e97 100644
--- a/content/browser/tab_contents/tab_contents.h
+++ b/content/browser/tab_contents/tab_contents.h
@@ -15,7 +15,7 @@
#include "base/gtest_prod_util.h"
#include "base/memory/scoped_ptr.h"
#include "base/string16.h"
-#include "chrome/browser/favicon_helper.h"
+#include "chrome/browser/favicon/favicon_tab_helper.h"
#include "chrome/browser/prefs/pref_change_registrar.h"
#include "chrome/browser/tab_contents/tab_specific_content_settings.h"
#include "chrome/browser/ui/app_modal_dialogs/js_modal_dialog.h"
@@ -163,9 +163,9 @@ class TabContents : public PageNavigator,
return view_.get();
}
- // Returns the FaviconHelper of this TabContents.
- FaviconHelper& favicon_helper() {
- return *favicon_helper_.get();
+ // Returns the FaviconTabHelper of this TabContents.
+ FaviconTabHelper& favicon_helper() {
+ return *favicon_tab_helper_.get();
}
// Tab navigation state ------------------------------------------------------
@@ -915,7 +915,7 @@ class TabContents : public PageNavigator,
BookmarkDrag* bookmark_drag_;
// Handles downloading favicons.
- scoped_ptr<FaviconHelper> favicon_helper_;
+ scoped_ptr<FaviconTabHelper> favicon_tab_helper_;
// RenderViewHost::ContentSettingsDelegate.
scoped_ptr<TabSpecificContentSettings> content_settings_delegate_;